'====================================================================================
'Script:       BartISO
'              Version 0.1 for PE-Builder 3.0.32
'              (c) 2004 LogicLink, Marcus Mller, distributed under GNU license
'              http://www.logiclink.de
'
'Description:  Makes an ISO image from Bart PE output files and preserves the upper
'              and lower case file names in the program directory. This is for a
'              cygwin plugin necessary as cygwin is case sensitive for file names.
'
'Installation: Copy this script, mkisofs.exe (version 2.01a29) and cygwin1.dll 
'              (version 1005.9.0.0) in a folder and run this script. For convenience
'              the constants OUT_DIR and ISO_PATH can be adjusted to the paths which
'              you use in the PE-Builder.
'              Remark: DO NOT REPLACE THE MKISOFS.EXE AND CYGWIN1.DLL IN THE 
'                      PE-BUILDER DIRECTORY AS THEY PRODUCE NOT BOOTABLE IMAGES WITH
'                      PE-BUILDER 3.0.32
'
'Further information you can find on
' http://www.cygwin.com for the cygwin environment
' http://www.nu2.nu/pebuilder/ for PE-Builder
' http://www.geoshock.com/cdrtools/ for cygwin mkisofs binaries
' http://www.fokus.gmd.de/research/cc/glone/employees/joerg.schilling/private/cdrecord.html
'====================================================================================

Option explicit

Const OUT_DIR = "C:\Temp"
Const ISO_PATH = "D:\pebuilder3032\pebuilder.iso"

Dim m_fso, m_sh, m_sOutDir, m_sIsoPath

'Convert file names of a folder to upper case
Sub ToUcase(cFolder, bRecursive)
	Dim f, fld, s
	For each f in cFolder.Files
		s = f.name 
		f.name = s & ".tmp"
		f.name = UCase(s)
	Next
	For each fld in cFolder.SubFolders
		s = fld.name 
		fld.name = s & ".tmp"
		fld.name = UCase(s)
		If bRecursive Then ToUcase fld, True
	Next
End Sub

'Get configuration
Function GetConfig()
	GetConfig = False
	
	MsgBox "Bart PE ISO script" & vbCrLf & vbCrLf & _
			"(c) 2004 LogicLink, Marcus Mller, distributed under GNU License." & vbCrLf & _
			"Version 0.1, 25.5.2004" & vbCrLf & vbCrLf & _
			"For information and new version visit www.logiclink.de", vbOKOnly, "Info:"

	m_sOutDir = InputBox("Enter the path of the output directory:", "Bart PE ISO script", OUT_DIR)
	If Len(m_sOutDir) = 0 Then Exit Function
	m_sIsoPath = InputBox("Enter the path and filename of the new ISO image:", "Bart PE ISO script", ISO_PATH)
	If Len(m_sOutDir) = 0 Then Exit Function
	GetConfig = True
End Function

'Main
if GetConfig() then

	'Rename files to upper case
	Set m_fso = CreateObject("Scripting.FileSystemObject")
	ToUcase m_fso.GetFolder(m_sOutDir), False
	ToUcase m_fso.GetFolder(m_sOutDir & "\i386"), True

	'Build iso image
	Set m_sh = WScript.CreateObject("WScript.Shell")
	m_sh.Run """" & Left(WScript.ScriptFullName, InStrRev(WScript.ScriptFullName, "\") - 1) & "\mkisofs.exe"" -iso-level 4 -volid ""BartPE"" -A PEBUILDER/MKISOFS -sysid ""Win32"" -b BOOTSECT.BIN -no-emul-boot -boot-load-size 4 -hide bootsect.bin -hide boot.catalog -o """ & m_sIsoPath & """ """ & m_sOutDir & """", , True
	MsgBox "ISO build finished.", ,"Bart PE ISO script"
End If
